@@ -5,14 +5,23 @@
 # inside a paragraph.
 
 
+def extract_tags_from_kwargs(kwargs):
+    tags_list = kwargs.pop("tags", "").split(",")
+
+    # Remove empty strings and return
+    return list(filter(None, tags_list))
+
+
 class Node:
     node_type = "node"
 
     def asdict(self):
         return {"type": self.node_type}  # pragma: no cover
 
+    def __eq__(self, other):
+        return self.asdict() == other.asdict()
+
 
-#############################################################
 # Inline elements
 
 
@@ -145,20 +154,25 @@ class MacroNode(Node):
 
     Attributes:
         value: the name of the macro
-        args (:obj:`tuple`): the unnamed arguments
-        kwargs (:obj:`dict`): the named arguments
+        arguments: the string of arguments
     """
 
     node_type = "macro"
 
-    def __init__(self, value, args=None, kwargs=None):
-        self.value = value
+    def __init__(self, name, args=None, kwargs=None):
+        self.name = name
         self.args = args or []
         self.kwargs = kwargs or {}
 
+        try:
+            self.value = self.args[0]
+        except IndexError:
+            self.value = None
+
     def asdict(self):
         return {
             "type": self.node_type,
+            "name": self.name,
             "value": self.value,
             "args": self.args,
             "kwargs": self.kwargs,
@@ -219,10 +233,10 @@ class ImageNode(Node):
         }
 
 
-class FootnoteRefNode(Node):
-    """Footnote reference.
+class FootnoteNode(Node):
+    """Footnote definition/reference.
 
-    This node contains a footnote reference.
+    This node contains a footnote definition or reference.
 
     Attributes:
        number: number of this footnote
@@ -230,7 +244,7 @@ class FootnoteRefNode(Node):
        defanchor: anchor ID of the definition
     """
 
-    node_type = "footnote_ref"
+    node_type = "footnote"
 
     def __init__(self, number, refanchor, defanchor, content):
         self.number = number
@@ -248,7 +262,14 @@ class FootnoteRefNode(Node):
         }
 
 
-#############################################################
+class FootnoteRefNode(FootnoteNode):
+    node_type = "footnote_ref"
+
+
+class FootnoteDefNode(FootnoteNode):
+    node_type = "footnote_def"
+
+
 # Block elements
 
 
@@ -259,6 +280,36 @@ class HorizontalRuleNode(Node):
         return {"type": "horizontal_rule"}
 
 
+class ContentNode(Node):
+    """Content included in the page.
+
+    This represents generic content included in the page.
+
+    Arguments:
+        uri: the URI of the image
+        title: caption of the image
+        args: unnamed arguments
+        kwargs: named arguments
+    """
+
+    node_type = "content"
+
+    def __init__(self, uri, title=None, args=None, kwargs=None):
+        self.uri = uri
+        self.title = title
+        self.kwargs = kwargs or {}
+        self.args = args or []
+
+    def asdict(self):
+        return {
+            "type": self.node_type,
+            "uri": self.uri,
+            "title": self.title.asdict() if self.title else None,
+            "args": self.args,
+            "kwargs": self.kwargs,
+        }
+
+
 class ContentImageNode(Node):
     """An image included in the page.
 
@@ -339,6 +390,7 @@ class HeaderNode(Node):
         self.level = level
         self.anchor = anchor
         self.kwargs = kwargs or {}
+        self.tags = extract_tags_from_kwargs(self.kwargs)
 
     def asdict(self):
         return {
@@ -346,6 +398,7 @@ class HeaderNode(Node):
             "value": self.value,
             "level": self.level,
             "anchor": self.anchor,
+            "tags": self.tags,
             "kwargs": self.kwargs,
         }
 
@@ -360,6 +413,9 @@ class BlockNode(Node):
         content: content of the block
         secondary_content: secondary content of this block
         title: title of this block
+        classes: a comma-separated list of classes
+        engine: the engine used to render this block
+        preprocessor: the preprocessor used for this block
         args: unnamed arguments
         kwargs: named arguments
     """
@@ -367,12 +423,24 @@ class BlockNode(Node):
     node_type = "block"
 
     def __init__(
-        self, blocktype, content, secondary_content, title=None, args=None, kwargs=None
+        self,
+        blocktype,
+        content,
+        secondary_content,
+        title=None,
+        classes=None,
+        engine=None,
+        preprocessor=None,
+        args=None,
+        kwargs=None,
     ):
         self.blocktype = blocktype
         self.content = content
         self.secondary_content = secondary_content
         self.title = title
+        self.classes = classes or []
+        self.engine = engine
+        self.preprocessor = preprocessor
         self.args = args or []
         self.kwargs = kwargs or {}
 
@@ -382,6 +450,9 @@ class BlockNode(Node):
             "blocktype": self.blocktype,
             "content": [i.asdict() for i in self.content],
             "secondary_content": [i.asdict() for i in self.secondary_content],
+            "classes": self.classes,
+            "engine": self.engine,
+            "preprocessor": self.preprocessor,
             "args": self.args,
             "kwargs": self.kwargs,
             "title": self.title.asdict() if self.title else None,
@@ -430,66 +501,6 @@ class SourceNode(Node):
         }
 
 
-class RawNode(Node):
-    """A block of raw content.
-
-    The content of this node will be inserted exactly as it is.
-
-    Arguments:
-        content: the content of the block
-        args: unnamed arguments
-        kwargs: named arguments
-    """
-
-    node_type = "raw"
-
-    def __init__(self, content, args=None, kwargs=None):
-        self.content = content
-        self.args = args or []
-        self.kwargs = kwargs or {}
-
-    def asdict(self):
-        return {
-            "type": self.node_type,
-            "content": [i.asdict() for i in self.content],
-            "args": self.args,
-            "kwargs": self.kwargs,
-        }
-
-
-class AdmonitionNode(Node):
-    """An admonition.
-
-    An admonition node that has a class, an icon, a label, and content.
-
-    Arguments:
-        admclass: the class of the admonition
-        icon: the icon assigned to this admonition
-        label: a label that acts as a title for the admonition
-        content: the content of the admonition
-        kwargs: named arguments
-    """
-
-    node_type = "admonition"
-
-    def __init__(self, admclass, icon, label, content, kwargs=None):
-        self.admclass = admclass
-        self.icon = icon
-        self.label = label
-        self.content = content
-        self.kwargs = kwargs or {}
-
-    def asdict(self):
-        return {
-            "type": self.node_type,
-            "class": self.admclass,
-            "icon": self.icon,
-            "label": self.label,
-            "content": [i.asdict() for i in self.content],
-            "kwargs": self.kwargs,
-        }
-
-
 class CommandNode(Node):
     """A Mau command.
 
@@ -504,6 +515,7 @@ class CommandNode(Node):
     node_type = "command"
 
     def __init__(self, name, args=None, kwargs=None):
+        self.args = args or []
         self.kwargs = kwargs or {}
         self.name = name
 
@@ -511,68 +523,48 @@ class CommandNode(Node):
         return {
             "type": self.node_type,
             "name": self.name,
+            "args": self.args,
             "kwargs": self.kwargs,
         }
 
 
-class QuoteNode(Node):
-    """A quote.
+class FootnotesNode(Node):
+    """A list of footnote definitions.
 
-    This node contains a quote with text and an attribution.
+    This node contains the footnote definitions.
 
     Arguments:
-        attribution: the attribution for this quote
-        content: the quote itself
-        kwargs: named arguments
+        entries: a list of FootnoteDefNode objects
     """
 
-    node_type = "quote"
+    node_type = "footnotes"
 
-    def __init__(self, attribution, content, kwargs=None):
-        self.attribution = attribution
-        self.content = content
-        self.kwargs = kwargs or {}
+    def __init__(self, entries=None):
+        self.entries = entries or []
 
     def asdict(self):
-        return {
-            "type": self.node_type,
-            "attribution": self.attribution,
-            "content": [i.asdict() for i in self.content],
-            "kwargs": self.kwargs,
-        }
-
-
-class FootnoteDefNode(Node):
-    """A footnote definition.
-
-    This node contains the definition of a footnote(i.e. the full text)
-
-    Arguments:
-        number: number of this footnote
-        refanchor: the ID of the reference of this footnote
-        defanchor: the ID of this definition
-        content: the full text of the footnote
-    """
-
-    node_type = "footnote_def"
-
-    def __init__(self, number, refanchor, defanchor, content):
-        self.number = number
-        self.refanchor = refanchor
-        self.defanchor = defanchor
-        self.content = content
-
-    def asdict(self):
-        return {
-            "type": self.node_type,
-            "refanchor": self.refanchor,
-            "defanchor": self.defanchor,
-            "number": self.number,
-            "content": [i.asdict() for i in self.content],
-        }
+        return {"type": self.node_type, "entries": [i.asdict() for i in self.entries]}
 
 
 class TocNode(Node):
+    """A Table of Contents.
+
+    This node contains the entries of the Table of Contents.
+
+    Arguments:
+        entries: a list of TocEntryNode objects
+    """
+
+    node_type = "toc"
+
+    def __init__(self, entries=None):
+        self.entries = entries or []
+
+    def asdict(self):
+        return {"type": self.node_type, "entries": [i.asdict() for i in self.entries]}
+
+
+class TocEntryNode(Node):
     """An entry of the Table of Contents.
 
     This node contains an entry of the Table of Contents.
@@ -586,18 +578,14 @@ class TocNode(Node):
 
     node_type = "toc_entry"
 
-    def __init__(self, level, text, anchor):
-        self.level = level
-        self.text = text
-        self.anchor = anchor
-        self.children = []
+    def __init__(self, header_node, children=None):
+        self.header = header_node
+        self.children = children or []
 
     def asdict(self):
         return {
             "type": self.node_type,
-            "level": self.level,
-            "text": self.text,
-            "anchor": self.anchor,
+            "header": self.header.asdict(),
             "children": [i.asdict() for i in self.children],
         }
 
