@@ -1,8 +1,10 @@
 import textwrap
-
 from unittest.mock import patch
 
+import pytest
+
 from mau.parsers.main_parser import MainParser
+from mau.visitors.visitor import CommandError
 from mau.visitors.html_visitor import HTMLVisitor
 
 from tests.helpers import (
@@ -24,7 +26,7 @@ def test_source(mock_highlight):
 
     source = textwrap.dedent(
         """
-        [source]
+        [myblock, engine=source]
         ----
         import os
 
@@ -33,7 +35,7 @@ def test_source(mock_highlight):
         """
     )
 
-    expected = ['<div class="code"><div class="content">XYXYXY</div></div>']
+    expected = ['<div class="myblock"><div class="content">XYXYXY</div></div>']
 
     _test(source, expected)
 
@@ -44,7 +46,7 @@ def test_source_indentation(mock_highlight):
 
     source = textwrap.dedent(
         """
-        [source,text]
+        [myblock, engine=source]
         ----
         Not indented
 
@@ -54,7 +56,7 @@ def test_source_indentation(mock_highlight):
     )
 
     expected = [
-        '<div class="code"><div class="content">Not indented\n\n    Indented</div></div>'
+        '<div class="myblock"><div class="content">Not indented\n\n    Indented</div></div>'
     ]
 
     _test(source, expected)
@@ -63,7 +65,7 @@ def test_source_indentation(mock_highlight):
 def test_source_callouts():
     source = textwrap.dedent(
         """
-        [source,callouts=":"]
+        [myblock, engine=source]
         ----
         Some code:1:
         
@@ -76,7 +78,7 @@ def test_source_callouts():
 
     expected = [
         (
-            '<div class="code">'
+            '<div class="myblock">'
             '<div class="content">'
             '<div class="highlight">'
             '<pre><span></span>Some code <span class="callout">1</span>\n\nSome other code <span class="callout">3</span>\n</pre>'
@@ -96,7 +98,7 @@ def test_source_callouts():
 def test_source_empty_callouts():
     source = textwrap.dedent(
         """
-        [source,callouts=":"]
+        [myblock, engine=source]
         ----
         Some code:1:
         
@@ -107,7 +109,7 @@ def test_source_empty_callouts():
 
     expected = [
         (
-            '<div class="code">'
+            '<div class="myblock">'
             '<div class="content">'
             '<div class="highlight">'
             '<pre><span></span>Some code <span class="callout">1</span>\n\nSome other code <span class="callout">3</span>\n</pre>'
@@ -122,7 +124,7 @@ def test_source_empty_callouts():
 def test_source_pygments_config():
     source = textwrap.dedent(
         """
-        [source,pygments.hl_lines="1,2,3"]
+        [myblock, engine=source, pygments.hl_lines="1,2,3"]
         ----
         import os
 
@@ -132,7 +134,7 @@ def test_source_pygments_config():
     )
 
     expected = [
-        '<div class="code"><div class="content"><div class="highlight"><pre><span></span><span class="hll">import os\n</span><span class="hll">\n</span><span class="hll">print(os.environ[&quot;HOME&quot;])\n</span></pre></div>\n</div></div>'
+        '<div class="myblock"><div class="content"><div class="highlight"><pre><span></span><span class="hll">import os\n</span><span class="hll">\n</span><span class="hll">print(os.environ[&quot;HOME&quot;])\n</span></pre></div>\n</div></div>'
     ]
 
     _test(source, expected)
@@ -141,7 +143,7 @@ def test_source_pygments_config():
 def test_source_highlights():
     source = textwrap.dedent(
         """
-        [source]
+        [myblock, engine=source]
         ----
         import os:@:
 
@@ -151,7 +153,49 @@ def test_source_highlights():
     )
 
     expected = [
-        '<div class="code"><div class="content"><div class="highlight"><pre><span></span><span class="hll">import os\n</span>\n<span class="hll">print(os.environ[&quot;HOME&quot;])\n</span></pre></div>\n</div></div>'
+        '<div class="myblock"><div class="content"><div class="highlight"><pre><span></span><span class="hll">import os\n</span>\n<span class="hll">print(os.environ[&quot;HOME&quot;])\n</span></pre></div>\n</div></div>'
     ]
 
     _test(source, expected)
+
+
+@patch("mau.visitors.html_visitor.highlight")
+def test_source_block_definition(mock_highlight):
+    mock_highlight.return_value = "XYXYXY"
+
+    source = textwrap.dedent(
+        """
+        ::defblock:source, myblock, engine=source
+
+        [source]
+        ----
+        import os
+
+        print(os.environ["HOME"])
+        ----
+        """
+    )
+
+    expected = ['<div class="myblock"><div class="content">XYXYXY</div></div>']
+
+    _test(source, expected)
+
+
+@patch("mau.visitors.html_visitor.highlight")
+def test_source_block_definition_variables_are_untouched(mock_highlight):
+    mock_highlight.return_value = "XYXYXY"
+
+    source = textwrap.dedent(
+        """
+        [source]
+        ----
+        a = 5
+
+        print(f"{a}")
+        ----
+        """
+    )
+
+    expected = ['<div class="source"><div class="content">XYXYXY</div></div>']
+
+    _test(source, expected)
